==> YUNoMakeGoodMap-1.10.2-6.1.0.22-sources.jar: net/minecraftforge/lex/yunomakegoodmap/generators/StructureLoader.java <==
package net.minecraftforge.lex.yunomakegoodmap.generators;

import java.io.File;

import com.google.common.base.Strings;

import net.minecraft.util.ResourceLocation;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;
import net.minecraft.world.WorldServer;
import net.minecraft.world.gen.structure.StructureBoundingBox;
import net.minecraft.world.gen.structure.template.PlacementSettings;
import net.minecraft.world.gen.structure.template.Template;
import net.minecraftforge.lex.yunomakegoodmap.StructureUtil;

public class StructureLoader implements IPlatformGenerator
{
    private String fileName;

    public StructureLoader(File baseDir, String fileName)
    {
        this.fileName = fileName;
    }


    @Override
    public void generate(World world, BlockPos pos)
    {
        PlacementSettings settings = new PlacementSettings();
        Template temp = null;
        String opts = world.func_72912_H().func_82571_y();
        if (!Strings.isNullOrEmpty(opts))
            temp = StructureUtil.loadTemplate(new ResourceLocation(opts), (WorldServer)world, true);
        if (temp == null)
            temp = StructureUtil.loadTemplate(new ResourceLocation("/config/", this.fileName), (WorldServer)world, false);

        BlockPos spawn = StructureUtil.findSpawn(temp, settings);
        if (spawn != null)
        {
            pos = pos.func_177973_b(spawn);
            world.func_175652_B(pos);
        }

        temp.func_189962_a(world, pos, settings, 0); //Push to world, with no neighbor notifications!
        world.func_175712_a(new StructureBoundingBox(pos, pos.func_177971_a(temp.func_186259_a())), true); //Remove block updates, so that sand doesn't fall!
    }
}

==> YUNoMakeGoodMap-1.11.2-6.2.0.27-sources.jar: net/minecraftforge/lex/yunomakegoodmap/generators/StructureLoader.java <==
package net.minecraftforge.lex.yunomakegoodmap.generators;

import java.io.File;

import com.google.common.base.Strings;

import net.minecraft.util.ResourceLocation;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;
import net.minecraft.world.WorldServer;
import net.minecraft.world.gen.structure.StructureBoundingBox;
import net.minecraft.world.gen.structure.template.PlacementSettings;
import net.minecraft.world.gen.structure.template.Template;
import net.minecraftforge.lex.yunomakegoodmap.StructureUtil;

public class StructureLoader implements IPlatformGenerator
{
    private String fileName;

    public StructureLoader(File baseDir, String fileName)
    {
        this.fileName = fileName;
    }

    @Override
    public void generate(World world, BlockPos pos)
    {
        PlacementSettings settings = new PlacementSettings();
        Template temp = null;
        String suffix = world.field_73011_w.func_186058_p().func_186067_c();
        String opts = world.func_72912_H().func_82571_y() + suffix;

        if (!Strings.isNullOrEmpty(opts))
            temp = StructureUtil.loadTemplate(new ResourceLocation(opts), (WorldServer)world, true);
        if (temp == null)
            temp = StructureUtil.loadTemplate(new ResourceLocation("/config/", this.fileName + suffix), (WorldServer)world, !Strings.isNullOrEmpty(suffix));
        if (temp == null)
            return; //If we're not in the overworld, and we don't have a template...

        BlockPos spawn = StructureUtil.findSpawn(temp, settings);
        if (spawn != null)
        {
            pos = pos.func_177973_b(spawn);
            world.func_175652_B(pos);
        }

        temp.func_189962_a(world, pos, settings, 0); //Push to world, with no neighbor notifications!
        world.func_175712_a(new StructureBoundingBox(pos, pos.func_177971_a(temp.func_186259_a())), true); //Remove block updates, so that sand doesn't fall!
    }
}
